;;****************************************************************************
;; FileName : WDLIB.ASM
;; Function : Control Watch Dog Time Out.(for ITE IT8712F)
;; Design's : By Ray
;; BuildDate: 11/27/2002 V1.1
;;****************************************************************************

;;Function declare as follows:
PUBLIC  InitWD          ;;initial watch dog
PUBLIC  EnWD            ;;enable watch dog
PUBLIC  DisWD           ;;disable watch dog
PUBLIC  OpenIoConfig    ;;open super IO of configuration register for Super I/O
PUBLIC  CloseIoConfig   ;;close super IO of configuration register for Super I/O
PUBLIC  SelectIoDevice  ;;select super IO of device for Super I/O
PUBLIC  WriteIoCR       ;;write super IO of configuration register for Super I/O
PUBLIC  ReadIoCR        ;;read super IO of configuration register for Super I/O

;;Default value define as follows:
equIndexPort EQU 2eh    ;;super IO of index port for Super I/O
equDataPort  EQU 2fh    ;;super IO of data port for Super I/O
equDeviceCR  EQU 07h    ;;select super IO device of index port for Super I/O
equLockReg   EQU 02h    ;;lock super IO of configuration register for Super I/O
;;equUnlockReg EQU 87h    ;;unlock super IO of configuration register for Super I/O

        .model  small
        .code
WatchDogLib:
;;
;;==========================================================================;;
;; OpenIoConfig                                                             ;;
;;==========================================================================;;
;; Function : open super IO of configuration register for Super I/O         ;;
;; Enter    : None                                                          ;;
;; Return   : None                                                          ;;
;; Change   : AL,DX                                                         ;;
;;==========================================================================;;
OpenIoConfig:
        mov     dx,equIndexPort ;;super IO of index port for Super I/O
        mov     al,87h		;;unlock super IO of configuration register for Super I/O
        out     dx,al
        nop
        nop
        mov	al,01h
        out     dx,al
        nop
        nop
        mov	al,55h
        out     dx,al
        nop
        nop
        mov	al,55h
        out     dx,al
	nop
	mop
	mov	al,22h
	out	dx,al
	nop
	nop
	mov	dx,equDataPort
	mov	al,00h
	out	dx,al
        ret
;;
;;==========================================================================;;
;; CloseIoConfig                                                            ;;
;;==========================================================================;;
;; Function : close super IO of configuration register for Super I/O        ;;
;; Enter    : None                                                          ;;
;; Return   : None                                                          ;;
;; Change   : AL,DX                                                         ;;
;;==========================================================================;;
CloseIoConfig:
        mov     dx,equIndexPort ;;super IO of index port for Super I/O
        mov	al,02h
        out	dx,al
        nop
        nop
        mov     dx,equDataPort  ;;super IO of data port for Super I/O
        mov     al,equLockReg   
        out     dx,al
        ret
;;
;;==========================================================================;;
;; SelectIoDevice                                                           ;;
;;==========================================================================;;
;; Function : select super IO of device for Super I/O                       ;;
;; Enter    : AH = select device of function                                ;;
;; Return   : None                                                          ;;
;; Change   : AX,DX                                                         ;;
;;==========================================================================;;
SelectIoDevice:
        mov     dx,equIndexPort ;;super IO of index port for Super I/O      
        mov     al,equDeviceCR  ;;select super IO device of index port for Super I/O
        out     dx,al
	nop
	nop
        mov     dx,equDataPort  ;;super IO of data port for Super I/O
        xchg    al,ah           ;;select device of function
        out     dx,al
        ret
;;
;;==========================================================================;;
;; WriteIoCR                                                                ;;
;;==========================================================================;;
;; Function : write super IO of configuration register for Super I/O        ;;
;; Enter    : AL = select index port of configuration register(CR)          ;;
;;            AH = configuration register of data                           ;;
;; Return   : None                                                          ;;
;; Change   : AX,DX                                                         ;;
;;==========================================================================;;
WriteIoCR:
        mov     dx,equIndexPort ;;super IO of index port for Super I/O
        out     dx,al
	nop
	nop
        mov     dx,equDataPort  ;;super IO of data port for Super I/O
        xchg    al,ah           ;;configuration register of data
	out     dx,al
        ret
;;
;;==========================================================================;;
;; ReadIoCR                                                                 ;;
;;==========================================================================;;
;; Function : read super IO of configuration register for Super I/O         ;;
;; Enter    : AL = select index port of configuration register(CR)          ;;
;; Return   : AL = configuration register of data                           ;;
;; Change   : AL,DX                                                         ;;
;;==========================================================================;;
ReadIoCR:
        mov     dx,equIndexPort ;;super IO of index port for Super I/O
        out     dx,al
	nop
	nop
        mov     dx,equDataPort  ;;super IO of data port for Super I/O
        in      al,dx           ;;configuration register of data
        ret
;;
;;==========================================================================;;
;; InitWD                                                                   ;;
;;==========================================================================;;
;; Function : initial watch dog                                             ;;
;; Enter    : BH = trigger signal					    ;;
;;                 40h : Reset                                              ;;
;;                 03h : IRQ3                                               ;;
;;                 04h : IRQ4                                               ;;
;;                 05h : IRQ5                                               ;;
;;                 06h : IRQ6                                               ;;
;;                 07h : IRQ7                                               ;;
;;                 09h : IRQ9                                               ;;
;;                 0ah : IRQ10                                              ;;
;;                 0bh : IRQ11                                              ;;
;;                 0ch : IRQ12                                              ;;
;;	      BL = watch dog counter of unit                                ;;
;;                 00h : minute                                             ;;
;;                 90h : second                                             ;;
;; Return   : None                                                          ;;
;; Change   : None                                                          ;;
;;==========================================================================;;
InitWD:
        push    ax
        push    bx
        push    dx

        call    OpenIoConfig    ;;open super IO of configuration for Super I/O

        mov     ah,07h          ;;select device7
        call    SelectIoDevice

	or	bh,bl
	mov	ah,bh
        mov     al,72h          ;;CR72 = ah , WatchDog initial
        call    WriteIoCR

;;	call    CloseIoConfig   ;;close super IO of configuration for Super I/O
        
        pop     dx
        pop     bx
        pop     ax
        ret
;;
;;==========================================================================;;
;; EnWD                                                                     ;;
;;==========================================================================;;
;; Function : Enable watch dog                                              ;;
;; Enter    : BL = watch dog time out of value                              ;;
;; Return   : None                                                          ;;
;; Change   : None                                                          ;;
;;==========================================================================;;
EnWD:
        push    ax
        push    bx
        push    dx

        call    OpenIoConfig    ;;open super IO of configuration for Super I/O

        mov     ah,07h          ;;select device7
        call    SelectIoDevice

	mov	ah,bl
        mov     al,73h          ;;CR73 = ah , Set WatchDog time out of vale
        call    WriteIoCR

	call    CloseIoConfig   ;;close super IO of configuration for Super I/O
	
        pop     dx
        pop     bx
        pop     ax
        ret
;;
;;==========================================================================;;
;; DisWD                                                                    ;;
;;==========================================================================;;
;; Function : Disable watch dog                                             ;;
;; Enter    : None                                                          ;;
;; Return   : None                                                          ;;
;; Change   : None                                                          ;;
;;==========================================================================;;
DisWD:
        push    ax
        push	bx
        push    dx


        call    OpenIoConfig    ;;open super IO of configuration for Super I/O

        mov     ah,07h          ;;select device7
        call    SelectIoDevice

	mov	ah,00h
        mov     al,73h          ;;CR73 = 00h , Disabled WatchDog
        call    WriteIoCR
        
        call    CloseIoConfig   ;;close super IO of configuration for Super I/O

        pop     dx
        pop	bx
        pop     ax
        ret
;;
;;==================== END ====================
        END     WatchDogLib
