;;****************************************************************************
;; FileName : WDLIB.H
;; Function : Watch Dog Library of Include File
;; Design's : By Ray
;; BuildDate: 11/27/2002 V1.1
;;****************************************************************************

;;External sub-program as follows:
EXTRN   InitWD:near             ;;Initial watch dog
EXTRN   EnWD:near               ;;Enable watch dog
EXTRN   DisWD:near              ;;Disable watch dog

;;Direct control register for Super I/O
;;(Referance the detail information of data sheet)
EXTRN   OpenIoConfig:near       ;;Enable register with Super I/O
EXTRN   CloseIoConfig:near      ;;Disable register with Super I/O
EXTRN   SelectIoDevice:near     ;;Select Watchdog or another device
EXTRN   WriteIoCR:near          ;;Write index data configuration register
EXTRN   ReadIoCR:near           ;;Read index data configuration register

;;Default value define as follows:
equWdUnitS EQU  90h             ;;Watch dog counter value of unit is second
equWdUnitM EQU  00h             ;;Watch dog counter value of unit is minute
RESET      EQU  40h             ;;RESET signal
IRQ3       EQU  03h             ;;IRQ3 signal
IRQ4       EQU  04h             ;;IRQ4 signal
IRQ5       EQU  05h             ;;IRQ5 signal
IRQ6       EQU  06h             ;;IRQ6 signal
IRQ7       EQU  07h             ;;IRQ7 signal
IRQ9       EQU  09h             ;;IRQ9 signal
IRQ10      EQU  0ah             ;;IRQ10 signal
IRQ11      EQU  0bh             ;;IRQ11 signal
IRQ12      EQU  0ch             ;;IRQ12 signal

;;use sub-program of method as follows:
;;
;;==========================================================================;;
;; OpenIoConfig                                                             ;;
;;==========================================================================;;
;; Function : Enable register with Super I/O                                ;;
;; Input    : None                                                          ;;
;; Return   : None                                                          ;;
;; Change   : AL,DX                                                         ;;
;;==========================================================================;;

;;==========================================================================;;
;; CloseIoConfig                                                            ;;
;;==========================================================================;;
;; Function : Disable register with Super I/O                               ;;
;; Input    : None                                                          ;;
;; Return   : None                                                          ;;
;; Change   : AL,DX                                                         ;;
;;==========================================================================;;

;;==========================================================================;;
;; SelectIoDevice                                                           ;;
;;==========================================================================;;
;; Function : Select Watchdog or another device                             ;;
;; Input    : AH = select device of function                                ;;
;; Return   : None                                                          ;;
;; Change   : AX,DX                                                         ;;
;;==========================================================================;;

;;==========================================================================;;
;; WriteIoCR                                                                ;;
;;==========================================================================;;
;; Function : Write index data register for Super I/O                       ;;
;; Input    : AL = select index port of configuration register(CR)          ;;
;;            AH = configuration register of data                           ;;
;; Return   : None                                                          ;;
;; Change   : AX,DX                                                         ;;
;;==========================================================================;;

;;==========================================================================;;
;; ReadIoCR                                                                 ;;
;;==========================================================================;;
;; Function : Read index data register for Super I/O                        ;;
;; Input    : AL = select index port of configuration register(CR)          ;;
;; Return   : AL = configuration register of data                           ;;
;; Change   : AL,DX                                                         ;;
;;==========================================================================;;

;;==========================================================================;;
;; InitWD                                                                   ;;
;;==========================================================================;;
;; Function : Initial watch dog                                             ;;
;; Input    : BH = trigger signal                                           ;;
;;                 40h : Reset                                              ;;
;;                 03h : IRQ3                                               ;;
;;                 04h : IRQ4                                               ;;
;;                 05h : IRQ5                                               ;;
;;                 06h : IRQ6                                               ;;
;;                 07h : IRQ7                                               ;;
;;                 09h : IRQ9                                               ;;
;;                 0ah : IRQ10                                              ;;
;;                 0bh : IRQ11                                              ;;
;;                 0ch : IRQ12                                              ;;
;;          : BL = watch dog counter of unit                                ;;
;;                 00h : minute                                             ;;
;;                 90h : second                                             ;;
;; Return   : None                                                          ;;
;; Change   : None                                                          ;;
;;==========================================================================;;

;;==========================================================================;;
;; EnWD                                                                     ;;
;;==========================================================================;;
;; Function : Enable watch dog                                              ;;
;; Input    : BL = watch dog time out of value                              ;;
;; Return   : None                                                          ;;
;; Change   : None                                                          ;;
;;==========================================================================;;

;;==========================================================================;;
;; DisWD                                                                    ;;
;;==========================================================================;;
;; Function : Disable watch dog                                             ;;
;; Input    : None                                                          ;;
;; Return   : None                                                          ;;
;; Change   : None                                                          ;;
;;==========================================================================;;
