/****************************************************************************/
/*                   Copyright(C) 2001 FabIATech Corporation                */
/* FileName : DEMO.C                                                        */
/* Function : Watch Dog of ITE8760 Program (for ITE8760E)                   */
/* Design's : By Eason Wu                                                   */
/* BuildDate: 04/12/2012 V1.1                                               */
/****************************************************************************/

/*Include file as follows:             */
#include <stdio.h>
#include <dos.h>
#include <dir.h>
#include <ITE8760.h>

/*Default value define as follows:     */
#define equIndexPort 0x2e                 /*super IO of index port for Super I/O               */
#define equDataPort 0x2f                  /*super IO of data port for Super I/O                */
#define equDeviceCR 0x07                  /*select super IO device of index port for Super I/O */
#define equWdUnit_Sec 0x80                /*watch dog counter value of unit is second*/
#define equWdUnit_Min 0x00                /*watch dog counter value of unit is minute*/
#define equReset 0x10                     /*watch dog counter value of unit is minute*/

/*Declaration function as follows:     */
void OpenIoConfig(void);                  /*open super IO of configuration register for Super I/O */
void CloseIoConfig(void);                 /*close super IO of configuration register for Super I/O */
void SelectIoDevice(char cSelectDEV);     /*select super IO of device for Super I/O   */
void WriteIoCR(char cIndex, char cData);  /*write super IO of configuration register for Supe I/O  */
char ReadIoCR(char cIndex);
void InitWD1(void);                      /*initial watch dog 1  Select SEC or Min value*/
void InitWD2(void);                      /*initial watch dog 2  Select SEC or Min value*/
void InitWD3(void);                      /*initial watch dog 3  Select SEC or Min value*/
void InitVaule1(void);                   /*initial watch dog 1  value*/
void InitVaule2(void);                   /*initial watch dog 2  value*/
void InitVaule3(void);                   /*initial watch dog 3  value*/
void IntWatchDogVaule1_Low(void);        /*initial watch dog 1  reset reg value (0~255)*/ 
void IntWatchDogVaule1_High_Low(void);   /*initial watch dog 1  reset reg value (256~65535)*/
void IntWatchDogVaule2_Low(void);        /*initial watch dog 2  reset reg value (0~255)*/ 
void IntWatchDogVaule2_High_Low(void);   /*initial watch dog 2  reset reg value (256~65535)*/
void IntWatchDogVaule3_Low(void);        /*initial watch dog 2  reset reg value (0~255)*/ 
void IntWatchDogVaule3_High_Low(void);   /*initial watch dog 2  reset reg value (256~65535)*/    
void DisWD(void);                         /*Disable watch dog  */
void Logo(void);                          /*Show  FabIATech Corp and Program Version:1.1  */

void main()
{ /*main_s */

char cInKey;

   clrscr();
   Logo();
   printf("Press <A> <B> <C> run Watch Dog<1>~<3>. \n");
   printf("Press <Q> or <q> quit program and disable watch dog. \n");
   printf("Please Input Key Value ==> 1");
   cInKey=getche();
   switch(cInKey)
     {/* switch_s1  */
     case 'A':
     case 'a':          
         InitWD1(); 
	     break;
     case 'B':
     case 'b':          
         InitWD2();	     
	     break;
     case 'C':
     case 'c':          
         InitWD3(); 	     
	     break;     
     case 'Q':
     case 'q':
	     printf("\n\nDisabled Watch Dog and Quit Programming.\n");
	     DisWD();        /* Disable Watch Dog Timer */
	     return;
     }/* switch_e1 */

} /*main_e */

/*==========================================================================*/
/* OpenIoConfig                                                             */
/*==========================================================================*/
/* Function : open super IO of configuration register for Super I/O         */
/* Enter    : None                                                          */
/* Return   : None                                                          */
/*==========================================================================*/
void OpenIoConfig(void)
{
/*super IO of index port for Super I/O */
outportb(equIndexPort,0x87);
outportb(equIndexPort,0x01);       /*Entry configuration mode  */
outportb(equIndexPort,0x55);       /*Entry configuration mode  */
outportb(equIndexPort,0x55);       /*Entry configuration mode  */
outportb(equIndexPort,0x22);       /*Entry configuration mode  */
outportb(equDataPort,0x00);       /*Entry configuration mode  */
}	
/*==========================================================================*/
/* SelectIoDevice                                                           */
/*==========================================================================*/
/* Function : select super IO of device for Super I/O                       */
/* Enter    : cSelectDEV = select device of function                        */
/* Return   : None                                                          */
/*==========================================================================*/
void SelectIoDevice(char cSelectDEV)
{
/*Open cofi*/     
OpenIoConfig();
/*super IO of index port for Super I/O  */
/*select super IO device of index port for Super I/O  */
outportb(equIndexPort,equDeviceCR);

/*super IO of data for Super I/O   */
/*select device of function        */
outportb(equDataPort,cSelectDEV);
}

/*==========================================================================*/
/* WriteIoCR                                                                */
/*==========================================================================*/
/* Function : write super IO of configuration register for Supe I/O         */
/* Enter    : cIndex = select index port of configuration register(CR)      */
/*            cData  = configuration register of data                       */
/* Return   : None                                                          */
/*==========================================================================*/
void WriteIoCR(char cIndex, char cData)
{
/*super IO of index port for Super I/O            */
/*select super IO of index register for Super I/O */
outportb(equIndexPort,cIndex);

/*super IO of data for Super I/O                  */
/*write data to data register                     */
outportb(equDataPort,cData);
}

/*==========================================================================*/
/* ReadIoCR                                                                 */
/*==========================================================================*/
/* Function : read super IO of configuration register for Super I/O         */
/* Enter    : cIndex = select index port of configuration register(CR)      */
/* Return   : configuration register of data		                        */
/*==========================================================================*/
char ReadIoCR(char cIndex)
{
/*super IO of index port for Super I/O*/
/*select super IO of index register for Supe I/O*/
outportb(equIndexPort,cIndex);

/*super IO of index port for Super I/O*/
/*read data form index register*/
return (inportb(equDataPort));
}


/*==========================================================================*/
/* InitWD1                                                                  */
/*==========================================================================*/
/* Function : initial watch dog                                             */
/* Enter    : cSetTriggerSignal						                        */
/*               10h : RESET                                                */
/*            cSetWatchDogUnit = watch dog counter of unit                  */
/*               00h : minute                                               */
/*               80h : second                                               */
/* Return   : None                                                          */
/*==========================================================================*/
void InitWD1(void)
{
char Key1;

OpenIoConfig();		/*open super IO of configuration for Super I/O*/

SelectIoDevice(0x07);	/*select device7*/
   printf("\nPress Slect <S>Sec or <M>Min run Watch Dog 1. \n");
   printf("Or press <Q> or <q> quit program and disable watch dog. \n");
   printf("Please Input Key Value ==> 2\n");
   Key1=getche();
   switch(Key1)
     {/* switch_s1  */
     case 'S':
     case 's':           
/*set watch dog counter of unit*/
         WriteIoCR(0x72, equWdUnit_Sec|equReset);
         InitVaule1();
	     break;
     case 'M':
     case 'm':          
         WriteIoCR(0x72, equWdUnit_Min|equReset);
         InitVaule1();
	     break;    
     case 'Q':
     case 'q':
	     printf("\n\nDisabled Watch Dog and Quit Programming.\n");
	     DisWD();
     return;
     }/* switch_e1 */

}/* InitWD1 */

/*==========================================================================*/
/* InitWD2                                                                  */
/*==========================================================================*/
/* Function : initial watch dog                                             */
/* Enter    : cSetTriggerSignal						                        */
/*               10h : RESET                                                */
/*            cSetWatchDogUnit = watch dog counter of unit                  */
/*               00h : minute                                               */
/*               80h : second                                               */
/* Return   : None                                                          */
/*==========================================================================*/
void InitWD2(void)
{
char InitWDKey2;
  
OpenIoConfig();		/*open super IO of configuration for Super I/O*/

SelectIoDevice(0x07);	/*select device7*/
   printf("\nPress Slect <S>Sec or <M>Min run Watch Dog 2. \n");
   printf("Or press <Q> or <q> quit program and disable watch dog. \n");
   printf("Please Input Key Value ==> 3\n");
   InitWDKey2=getche();
   switch(InitWDKey2)
     {/* switch_s1  */
     case 'S':
     case 's':           
/*set watch dog counter of unit*/
         WriteIoCR(0x82, equWdUnit_Sec|equReset);
         InitVaule2();
	     break;
     case 'M':
     case 'm':
         WriteIoCR(0x82, equWdUnit_Min|equReset);
         InitVaule2();
         break;	     
     case 'Q':
     case 'q':
	     printf("\n\nDisabled Watch Dog and Quit Programming.\n");
	     DisWD();
     return;
     }/* switch_e1 */

}/* InitWD2 */

/*==========================================================================*/
/* InitWD3                                                                  */
/*==========================================================================*/
/* Function : initial watch dog3                                            */
/* Enter    : cSetTriggerSignal			                    			    */
/*               10h : RESET                                                */
/*            cSetWatchDogUnit = watch dog counter of unit                  */
/*               00h : minute                                               */
/*               80h : second                                               */
/* Return   : None                                                          */
/*==========================================================================*/
void InitWD3(void)
{
char I3nitWDKey;
      
OpenIoConfig();		/*open super IO of configuration for Super I/O*/

SelectIoDevice(0x07);	/*select device7*/
   printf("\nPress Slect <S>Sec or <M>Min run Watch Dog 3. \n");
   printf("Or press <Q> or <q> quit program and disable watch dog. \n");
   printf("Please Input Key Value ==> 4\n");
   I3nitWDKey=getche();
   switch(I3nitWDKey)
     {/* switch_s1  */
     case 'S':
     case 's':          
/*set watch dog counter of unit*/
         WriteIoCR(0x92, equWdUnit_Sec|equReset);
         InitVaule3();
	     break;
     case 'M':
     case 'm':          
         WriteIoCR(0x92, equWdUnit_Min|equReset);
         InitVaule3();
	     break;   
     case 'Q':
     case 'q':
	     printf("\n\nDisabled Watch Dog and Quit Programming.\n");
	     DisWD();                    
     return;
     }/* switch_e1 */

}/* InitWD3 */

/*==========================================================================*/
/* InitVaule1                                                               */
/*==========================================================================*/
/* Function : initial watch dog  vaule                                      */
/* Enter    : 	 73h : 0~255 					                            */
/*               74h : 256~65536                                            */
/* Return   : None                                                          */
/*==========================================================================*/
void InitVaule1 (void)
{
char K1ey;

OpenIoConfig();		                                                      /*open super IO of configuration for Super I/O*/

SelectIoDevice(0x07);	                                                  /*select device7*/
   printf("Press Slect <E> or <F> run Watch Dog 1 Formate vaule.          \n");
   printf("Select <E> or <e> and Enter Formate  is 0xFF(0~255).           \n");
   printf("Select <F> or <f> and Enter Formate  is 0xFFFF (0~65535).      \n");
   printf("Or press <Q> or <q> quit program and disable watch dog.        \n");
   printf("Please Input Key Value ==> 5\n");
   K1ey=getche();
   switch(K1ey)
     {/* switch_s1  */
     case 'E':
     case 'e':          
         IntWatchDogVaule1_Low();                                          /*set watch dog1 counter of Vaule (0~255)*/
         break;
     case 'F':
     case 'f':          
         IntWatchDogVaule1_High_Low();                                     /*set watch dog1 counter of Vaule (0~65535)*/
         break;     
     case 'Q':
     case 'q':
	     printf("\n\nDisabled Watch Dog and Quit Programming.\n");
	     DisWD(); 
     return;
     }/* switch_e1 */

}/* InitWD1 */


/*==========================================================================*/
/* InitVaule2                                                               */
/*==========================================================================*/
/* Function : initial watch dog2  vaule                                     */
/* Enter    : 	 83h : 0~255 					                            */
/*               84h : 256~65536                                            */
/* Return   : None                                                          */
/*==========================================================================*/
void InitVaule2 (void)
{
char Ke2y;

OpenIoConfig();		                                                      /*open super IO of configuration for Super I/O*/

SelectIoDevice(0x07);	                                                  /*select device7*/
   printf("\nPress Slect <E> or <F> run Watch Dog 2 Formate vaule.       \n");
   printf("Select <E> or <e> and Enter Formate  is 0xFF(0~255).          \n");
   printf("Select <F> or <f> and Enter Formate  is 0xFFFF (0~65535).     \n");
   printf("Or press <Q> or <q> quit program and disable watch dog. \n");
   printf("Please Input Key Value ==> 6\n");
   Ke2y=getche();
   switch(Ke2y)
     {/* switch_s1  */
     case 'E':
     case 'e':          
         IntWatchDogVaule2_Low();                                          /*set watch dog2 counter of Vaule (0~255)*/
         break;
     case 'F':
     case 'f':          
         IntWatchDogVaule2_High_Low();                                   /*set watch dog2 counter of Vaule (0~65535)*/
         break;     
     case 'Q':
     case 'q':
	     printf("\n\nDisabled Watch Dog and Quit Programming.\n");
	     DisWD();          
     return;
     }/* switch_e1 */

}/* InitWD1 */

/*==========================================================================*/
/* InitVaule3                                                               */
/*==========================================================================*/
/* Function : initial watch dog3  vaule                                     */
/* Enter    : 	 93h : 0~255 					                            */
/*               94h : 256~65536                                            */
/* Return   : None                                                          */
/*==========================================================================*/
void InitVaule3 (void)
{
char Key3;

OpenIoConfig();		                                                      /*open super IO of configuration for Super I/O*/

SelectIoDevice(0x07);	                                                  /*select device7*/
   printf("\nPress Slect <E> or <F> run Watch Dog 3 Formate vaule.       \n");
   printf("Select <E> or <e> and Enter Formate  is 0xFF(0~255).          \n");
   printf("Select <F> or <f> and Enter Formate  is 0xFFFF (0~65535).     \n");
   printf("Or press <Q> or <q> quit program and disable watch dog. \n");
   printf("Please Input Key Value ==> 7\n");
   Key3=getche();
   switch(Key3)
     {/* switch_s1  */
     case 'E':
     case 'e':          
         IntWatchDogVaule3_Low();                                          /*set watch dog3 counter of Vaule (0~255)*/
         break;
     case 'F':
     case 'f':          
         IntWatchDogVaule3_High_Low();                                   /*set watch dog3 counter of Vaule (0~65535)*/
         break;     
     case 'Q':
     case 'q':
	     printf("\n\nDisabled Watch Dog and Quit Programming.\n");
	     DisWD();          
     return;
     }/* switch_e1 */

}/* InitWD1 */


/*==========================================================================*/
/* IntWatchDogVaule1_Low                                                    */
/*==========================================================================*/
/* Function : IntWatchDogVaule1_Low                                         */
/* Enter    : cWatchDogValue = watch dog time out of value  (0~255)         */
/* Return   : None                                                          */
/*==========================================================================*/
void IntWatchDogVaule1_Low(void)
{
long char cWatchDogValue1_Low;    /*Set Watch Dog1 Timer Output  vaule*/


OpenIoConfig();			/*open super IO of configuration for Supe I/O*/

SelectIoDevice(0x07);	/*select device7*/

/*Tigger WatchDog*/
printf("\nEnter Key Value Formate is oxFF(0~255).\n");                 
scanf("%li",&cWatchDogValue1_Low);                                    /*Set WatchDog value Low byte reg73 */ 
WriteIoCR(0x73, cWatchDogValue1_Low);

}

/*==========================================================================*/
/* IntWatchDogVaule1_High_Low                                               */
/*==========================================================================*/
/* Function : IntWatchDogVaule1                                             */
/* Enter    : cWatchDogValue = watch dog time out of value (0~65535)        */
/* Return   : None                                                          */
/*==========================================================================*/
void IntWatchDogVaule1_High_Low(void)
{
long char cWatchDogValue1_Low;                                    /*Set Watch Dog1 Timer Second Output */
long char cWatchDogValue1_High;                               /*Set Watch Dog1 Timer Minute Output */

OpenIoConfig();			                                               /*open super IO of configuration for Supe I/O*/

SelectIoDevice(0x07);	                                               /*select device7*/

                                                                       /*Tigger WatchDog*/
printf("\nEnter Key Value Formate is oxFF(0~255).\n");                 
scanf("%li",&cWatchDogValue1_Low);                                     /*Set WatchDog value Low byte reg73 */ 
WriteIoCR(0x73, cWatchDogValue1_Low); 

printf("\nEnter Key Value Formate is oxFF(256~65535).\n");
scanf("%li",&cWatchDogValue1_High);                                    /*Set WatchDog value Low byte reg74 */ 
WriteIoCR(0x74, cWatchDogValue1_High);

}



/*==========================================================================*/
/* IntWatchDogVaule2_Low                                                    */
/*==========================================================================*/
/* Function : IntWatchDogVaule2_Low                                         */
/* Enter    : cWatchDogValue2_Low = watch dog time out of value  (0~255)    */
/* Return   : None                                                          */
/*==========================================================================*/
void IntWatchDogVaule2_Low(void)
{
long char cWatchDogValue2_Low=0x00;                                    /*Set Watch Dog1 Timer Output  vaule*/


OpenIoConfig();			                                               /*open super IO of configuration for Supe I/O*/

SelectIoDevice(0x07);	                                               /*select device7*/

                                                                       /*Tigger WatchDog*/
printf("\nEnter Key Value Formate is oxFF(0~255).\n");                 
scanf("%li",&cWatchDogValue2_Low);                                     /*Set WatchDog value Low byte reg83 */ 
WriteIoCR(0x83, cWatchDogValue2_Low);

}

/*==========================================================================*/
/* IntWatchDogVaule2_High_Low                                               */
/*==========================================================================*/
/* Function : IntWatchDogVaule2                                             */
/* Enter    : cWatchDogValue = watch dog time out of value (0~65535)        */
/* Return   : None                                                          */
/*==========================================================================*/
void IntWatchDogVaule2_High_Low(void)
{
long char cWatchDogValue2_Low=0x00;                                    /*Set Watch Dog2 Timer Second Output */
long char cWatchDogValue2_High=0x00;                               /*Set Watch Dog2 Timer Minute Output */

OpenIoConfig();			                                               /*open super IO of configuration for Supe I/O*/

SelectIoDevice(0x07);	                                               /*select device7*/
                                                                       /*Tigger WatchDog*/
printf("\nEnter Key Value Formate is oxFF(0~255).\n");                 
scanf("%li",&cWatchDogValue2_Low);                                     /*Set WatchDog value Low byte reg83 */ 
WriteIoCR(0x83, cWatchDogValue2_Low); 

printf("\nEnter Key Value Formate is oxFF(256~65535).\n");
scanf("%li",&cWatchDogValue2_High);                                    /*Set WatchDog value Low byte reg84 */ 
WriteIoCR(0x84, cWatchDogValue2_High);

}


/*==========================================================================*/
/* IntWatchDogVaule3_Low                                                    */
/*==========================================================================*/
/* Function : IntWatchDogVaule3_Low                                         */
/* Enter    : cWatchDogValue3_Low = watch dog time out of value  (0~255)    */
/* Return   : None                                                          */
/*==========================================================================*/
void IntWatchDogVaule3_Low(void)
{
long char cWatchDogValue3_Low=0x00;                                    /*Set Watch Dog3 Timer Output  vaule*/


OpenIoConfig();			                                               /*open super IO of configuration for Supe I/O*/

SelectIoDevice(0x07);	                                               /*select device7*/

                                                                       /*Tigger WatchDog*/
printf("\nEnter Key Value Formate is oxFF(0~255).\n");                 
scanf("%li",&cWatchDogValue3_Low);                                     /*Set WatchDog value Low byte reg93 */ 
WriteIoCR(0x93, cWatchDogValue3_Low);

}

/*==========================================================================*/
/* IntWatchDogVaule3_High_Low                                               */
/*==========================================================================*/
/* Function : IntWatchDogVaule1                                             */
/* Enter    : cWatchDogValue = watch dog time out of value (0~65535)        */
/* Return   : None                                                          */
/*==========================================================================*/
void IntWatchDogVaule3_High_Low(void)
{
long char cWatchDogValue3_Low=0x00;                                    /*Set Watch Dog3 Timer Second Output */
long char cWatchDogValue3_High=0x00;                               /*Set Watch Dog3 Timer Minute Output */

OpenIoConfig();			                                               /*open super IO of configuration for Supe I/O*/

SelectIoDevice(0x07);
	                                               /*select device7*/

                                                                       /*Tigger WatchDog*/
printf("\nEnter Key Value Formate is oxFF(0~255).\n");                 
scanf("%li",&cWatchDogValue3_Low);                                     /*Set WatchDog value Low byte reg73 */ 
WriteIoCR(0x93, cWatchDogValue3_Low); 

printf("\nEnter Key Value Formate is oxFF(256~65535).\n");
scanf("%li",&cWatchDogValue3_High);   
WriteIoCR(0x94, cWatchDogValue3_High);
}
/*==========================================================================*/
/* CloseIoConfig                                                            */
/*==========================================================================*/
/* Function : close super IO of configuration register for Super I/O        */
/* Enter    : None                                                          */
/* Return   : None                                                          */
/*==========================================================================*/
void CloseIoConfig(void)
{
/*super IO of index port for Super I/O*/
/*lock super IO of configuration register for Super I/O*/
outportb(equIndexPort,0x02);
outportb(equDataPort,0x02);
}

/*==========================================================================*/
/* DisWD                                                                    */
/*==========================================================================*/
/* Function : Disable watch dog                                             */
/* Enter    : None              					                        */
/* Return   : None                                                          */
/*==========================================================================*/
void DisWD(void)
{
OpenIoConfig();			/*open super IO of configuration for Supe I/O*/

SelectIoDevice(0x07);		/*select device7*/

WriteIoCR(0x73, 0x00);

CloseIoConfig();		/*close super IO of configuration for Super I/O*/
}

/*==========================================================================*/
/* Logo                                                                     */
/*==========================================================================*/
/* Function : Show  FabIATech Corp and Program Version:1.1                  */
/* Enter    : None              					                        */
/* Return   : None                                                          */
/*==========================================================================*/
void Logo(void)
{
printf("    =======================================================================\n");
printf("    ||Watch Dog Timer of Program from FabIATech Corp                     ||\n");
printf("    ||This program is design for test Watch Dog Timer for ITE 8760      .||\n");
printf("    ||Program Version:1.1 Copyright(C) 04/12/2012 by Eason Wu.           ||\n");
printf("    =======================================================================\n");
}
