/****************************************************************************/
/*                   Copyright(C) 2001 FabIATech Corporation                */
/* FileName : DEMO.H                                                        */
/* Function : Watch Dog of F81216D Program (for FINTEK F81216D)             */
/* Design's : By Jimmy Chang                                                */
/* BuildDate: 26/04/2006 V1.1                                               */
/****************************************************************************/
#ifndef __WDLIB_H
#define __WDLIB_H

#ifndef __DOS_H
  #include <dos.h>
#endif

/*Default value define as follows: */
#define equWdUnitS 0x03 /*watch dog counter value of unit is second */
#define equWdUnitM 0x05 /*watch dog counter value of unit is minute */

#ifdef __cplusplus
extern "C" {
#endif

/*==========================================================================*/
/* OpenIoConfig                                                             */
/*==========================================================================*/
/* Function : open super IO of configuration register for Super I/O         */
/* Enter    : None                                                          */
/* Return   : None                                                          */
/*==========================================================================*/
void OpenIoConfig(void);

/*==========================================================================*/
/* CloseIoConfig                                                            */
/*==========================================================================*/
/* Function : close super IO of configuration register for Super I/O        */
/* Enter    : None                                                          */
/* Return   : None                                                          */
/*==========================================================================*/
void CloseIoConfig(void);

/*==========================================================================*/
/* SelectIoDevice                                                           */
/*==========================================================================*/
/* Function : select super IO of device for Super I/O                       */
/* Enter    : cSelectDEV = select device of function                        */
/* Return   : None                                                          */
/*==========================================================================*/
void SelectIoDevice(char cSelectDEV);

/*==========================================================================*/
/* WriteIoCR                                                                */
/*==========================================================================*/
/* Function : write super IO of configuration register for Supe I/O         */
/* Enter    : cIndex = select index port of configuration register(CR)      */
/*            cData  = configuration register of data                       */
/* Return   : None                                                          */
/*==========================================================================*/
void WriteIoCR(char cIndex, char cData);

/*==========================================================================*/
/* InitWD1                                                                  */
/*==========================================================================*/
/* Function : initial watch dog1                                            */
/* Enter    : cSetTriggerSignal			                    			    */
/*               10h : RESET                                                */
/*            cSetWatchDogUnit = watch dog counter of unit                  */
/*               00h : minute                                               */
/*               80h : second                                               */
/* Return   : None                                                          */
/*==========================================================================*/
void InitWD1(void);
/*==========================================================================*/
/* InitWD2                                                                  */
/*==========================================================================*/
/* Function : initial watch dog2                                            */
/* Enter    : cSetTriggerSignal			                    			    */
/*               10h : RESET                                                */
/*            cSetWatchDogUnit = watch dog counter of unit                  */
/*               00h : minute                                               */
/*               80h : second                                               */
/* Return   : None                                                          */
/*==========================================================================*/
void InitWD2(void);

/*==========================================================================*/
/* InitWD3                                                                  */
/*==========================================================================*/
/* Function : initial watch dog3                                            */
/* Enter    : cSetTriggerSignal			                    			    */
/*               10h : RESET                                                */
/*            cSetWatchDogUnit = watch dog counter of unit                  */
/*               00h : minute                                               */
/*               80h : second                                               */
/* Return   : None                                                          */
/*==========================================================================*/
void InitWD3(void);

/*==========================================================================*/
/* InitVaule1                                                               */
/*==========================================================================*/
/* Function : initial watch dog  vaule                                      */
/* Enter    : 	 73h : 0~255 					                            */
/*               74h : 256~65536                                            */
/* Return   : None                                                          */
/*==========================================================================*/
void InitVaule1(void);

/*==========================================================================*/
/* InitVaule2                                                               */
/*==========================================================================*/
/* Function : initial watch dog  vaule                                      */
/* Enter    : 	 83h : 0~255 					                            */
/*               84h : 256~65536                                            */
/* Return   : None                                                          */
/*==========================================================================*/
void InitVaule2(void);

/*==========================================================================*/
/* InitVaule3                                                               */
/*==========================================================================*/
/* Function : initial watch dog  vaule                                      */
/* Enter    : 	 83h : 0~255 					                            */
/*               84h : 256~65536                                            */
/* Return   : None                                                          */
/*==========================================================================*/
void InitVaule3(void);

/*==========================================================================*/
/* IntWatchDogVaule1_Low                                                    */
/*==========================================================================*/
/* Function : IntWatchDogVaule1_Low                                         */
/* Enter    : cWatchDogValue = watch dog 1 time out of value  (0~255)       */
/* Return   : None                                                          */
/*==========================================================================*/
void IntWatchDogVaule1_Low (void);

/*==========================================================================*/
/* IntWatchDogVaule1_High_Low                                               */
/*==========================================================================*/
/* Function : IntWatchDogVaule1_High_Low                                    */
/* Enter    : cWatchDogValue = watch dog 1 time out of value (256~65535)    */
/* Return   : None                                                          */
/*==========================================================================*/
void IntWatchDogVaule1_High_Low (void);

/*==========================================================================*/
/* IntWatchDogVaule2_Low                                                    */
/*==========================================================================*/
/* Function : IntWatchDogVaule2_Low                                         */
/* Enter    : cWatchDogValue = watch dog 2 time out of value  (0~255)       */
/* Return   : None                                                          */
/*==========================================================================*/
void IntWatchDogVaule2_Low (void);

/*==========================================================================*/
/* IntWatchDogVaule2_High_Low                                               */
/*==========================================================================*/
/* Function : IntWatchDogVaule2_High_Low                                    */
/* Enter    : cWatchDogValue = watch dog 2 time out of value (256~65535)    */
/* Return   : None                                                          */
/*==========================================================================*/
void IntWatchDogVaule2_High_Low (void);

/*==========================================================================*/
/* IntWatchDogVaule3_Low                                                    */
/*==========================================================================*/
/* Function : IntWatchDogVaule1_Low                                         */
/* Enter    : cWatchDogValue = watch dog 3 time out of value  (0~255)       */
/* Return   : None                                                          */
/*==========================================================================*/
void IntWatchDogVaule3_Low (void);

/*==========================================================================*/
/* IntWatchDogVaule3_High_Low                                               */
/*==========================================================================*/
/* Function : IntWatchDogVaule3_High_Low                                    */
/* Enter    : cWatchDogValue = watch dog 3 time out of value (256~65535)    */
/* Return   : None                                                          */
/*==========================================================================*/
void IntWatchDogVaule3_High_Low (void);

/*==========================================================================*/
/* DisWD                                                                    */
/*==========================================================================*/
/* Function : Disable watch dog                                            */
/* Enter    : None              					                        */
/* Return   : None                                                          */
/*==========================================================================*/
void DisWD(void);

/*==========================================================================*/
/* Logo                                                                     */
/*==========================================================================*/
/* Function : Show  FabIATech Corp and Program Version:1.1                  */
/* Enter    : None              					                        */
/* Return   : None                                                          */
/*==========================================================================*/
void Logo();

#ifdef __cplusplus
}
#endif

#endif  // __WDLIB_H
