//****************************************************************************
// FileName : WDLIB.H
// Function : Watch Dog Function Define of Include File
// Design's : By Ray
// BuildDate: 11/27/2002 V1.1
//****************************************************************************
#ifndef __WDLIB_H
#define __WDLIB_H

#ifndef __DOS_H
  #include <dos.h>
#endif

//Default value define as follows:
#define equWdUnitS 0x80 //watch dog counter value of unit is second
#define equWdUnitM 0x00 //watch dog counter value of unit is minute
#define RESET 0x40      //RESET signal
#define IRQ3  0x03      //IRQ3 signal
#define IRQ4  0x04      //IRQ4 signal
#define IRQ5  0x05      //IRQ5 signal
#define IRQ6  0x06      //IRQ6 signal
#define IRQ7  0x07      //IRQ7 signal
#define IRQ9  0x09      //IRQ9 signal
#define IRQ10 0x0a      //IRQ10 signal
#define IRQ11 0x0b      //IRQ11 signal
#define IRQ12 0x0c      //IRQ12 signal

#ifdef __cplusplus
extern "C" {
#endif

//==========================================================================//
// InitWD                                                                   //
//==========================================================================//
// Function : Initial watch dog                                             //
// Input    : cSetTriggerSignal                                             //
//               40h : RESET                                                //
//               03h : IRQ3                                                 //
//               04h : IRQ4                                                 //
//               05h : IRQ5                                                 //
//               06h : IRQ6                                                 //
//               07h : IRQ7                                                 //
//               09h : IRQ9                                                 //
//               0ah : IRQ10                                                //
//               0bh : IRQ11                                                //
//               0ch : IRQ12                                                //
//            cSetWatchDogUnit = watch dog counter of unit                  //
//               00h : minute                                               //
//               80h : second                                               //
// Return   : None                                                          //
//==========================================================================//
void InitWD(char cSetWatchDogUnit, char cSetTriggerSignal);

//==========================================================================//
// EnWD                                                                     //
//==========================================================================//
// Function : Enable watch dog                                              //
// Input    : cWatchDogValue = watch dog time out of value                  //
// Return   : None                                                          //
//==========================================================================//
void EnWD(char cWatchDogValue);

//==========================================================================//
// DisWD                                                                    //
//==========================================================================//
// Function : Disable watch dog                                             //
// Input    : None                                                          //
// Return   : None                                                          //
//==========================================================================//
void DisWD(void);


/*Direct control register for IO Super I/O
  (Referance the detail information of data sheet)*/
//==========================================================================//
// OpenIoConfig                                                             //
//==========================================================================//
// Function : Enable register with Super I/O                                //
// Input    : None                                                          //
// Return   : None                                                          //
//==========================================================================//
void OpenIoConfig(void);

//==========================================================================//
// CloseIoConfig                                                            //
//==========================================================================//
// Function : Disable register with Super I/O                               //
// Input    : None                                                          //
// Return   : None                                                          //
//==========================================================================//
void CloseIoConfig(void);

//==========================================================================//
// SelectIoDevice                                                           //
//==========================================================================//
// Function : Select Watchdog or another device                             //
// Input    : cSelectDEV = select device of function                        //
// Return   : None                                                          //
//==========================================================================//
void SelectIoDevice(char cSelectDEV);

//==========================================================================//
// WriteIoCR                                                                //
//==========================================================================//
// Function : Write index data configuration register for Super I/O         //
// Input    : cIndex = select index port of configuration register(CR)      //
//            cData  = configuration register of data                       //
// Return   : None                                                          //
//==========================================================================//
void WriteIoCR(char cIndex, char cData);

//==========================================================================//
// ReadIoCR                                                                 //
//==========================================================================//
// Function : Read index data configuration register for Super I/O          //
// Input    : cIndex = select index port of configuration register(CR)      //
// Return   : configuration register of data                                //
//==========================================================================//
char ReadIoCR(char cIndex);

#ifdef __cplusplus
}
#endif

#endif  // __WDLIB_H
